# GraphicalImageProcessing


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**statistics** | [**GraphicalImageStatistics**](GraphicalImageStatistics.md) |  | [optional] 

## Example

```python
from openapi_client.models.graphical_image_processing import GraphicalImageProcessing

# TODO update the JSON string below
json = "{}"
# create an instance of GraphicalImageProcessing from a JSON string
graphical_image_processing_instance = GraphicalImageProcessing.from_json(json)
# print the JSON string representation of the object
print GraphicalImageProcessing.to_json()

# convert the object into a dict
graphical_image_processing_dict = graphical_image_processing_instance.to_dict()
# create an instance of GraphicalImageProcessing from a dict
graphical_image_processing_form_dict = graphical_image_processing.from_dict(graphical_image_processing_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


